==> librcsc-1.4.0.tar.gz: librcsc-1.4.0/rcsc/action/body_shoot.h <==
// -*-c++-*-

/*!
  \file body_shoot.h
  \brief advanced shoot planning and action.
*/

/*
 *Copyright:

 Copyright (C) Hidehisa AKIYAMA

 This code is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 *EndCopyright:
 */

/////////////////////////////////////////////////////////////////////

#ifndef RCSC_ACTION_BODY_SHOOT_H
#define RCSC_ACTION_BODY_SHOOT_H

#include "shoot_table.h"

#include <rcsc/player/soccer_action.h>

namespace rcsc {

/*!
  \class Body_Shoot
  \brief advanced shoot planning and behavior.
 */
class Body_Shoot
    : public BodyAction {
private:
    //! cached shoot talbe
    static ShootTable S_shoot_table;

public:
    /*!
      \brief accessible from global.
     */
    Body_Shoot()
      { }

    /*!
      \brief execute action
      \param agent pointer to the agent itself
      \return true if action is performed
     */
    bool execute( PlayerAgent * agent );


    /*!
      \brief get the current shoot table
      \return const reference to the shoot table instance.
     */
    static
    const
    ShootTable & get_shoot_table( const PlayerAgent * agent )
      {
          return S_shoot_table;
      }

};

}

#endif

==> librcsc-2.0.1.tar.gz: librcsc-2.0.1/rcsc/action/body_shoot.h <==
// -*-c++-*-

/*!
  \file body_shoot.h
  \brief advanced shoot planning and action.
*/

/*
 *Copyright:

 Copyright (C) Hidehisa AKIYAMA

 This code is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 *EndCopyright:
 */

/////////////////////////////////////////////////////////////////////

#ifndef RCSC_ACTION_BODY_SHOOT_H
#define RCSC_ACTION_BODY_SHOOT_H

#include "shoot_table.h"

#include <rcsc/player/soccer_action.h>

namespace rcsc {

/*!
  \class Body_Shoot
  \brief advanced shoot planning and behavior.
 */
class Body_Shoot
    : public BodyAction {
private:
    //! cached shoot table
    static ShootTable S_shoot_table;

public:
    /*!
      \brief accessible from global.
     */
    Body_Shoot()
      { }

    /*!
      \brief execute action
      \param agent pointer to the agent itself
      \return true if action is performed
     */
    bool execute( PlayerAgent * agent );


    /*!
      \brief get the current shoot table
      \return const reference to the shoot table instance.
     */
    static
    const
    ShootTable & get_shoot_table( const PlayerAgent * agent )
      {
          return S_shoot_table;
      }

};

}

#endif
